<?php

namespace EXOTEC\Questionaire\Hooks;

/**
 * This file is part of the "questionaire" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 */

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Utility\DebuggerUtility;

/**
 * AutoConfiguration-Hook for RealURL
 *
 */
class RealUrlAutoConfiguration
{

    /**
     * Generates additional RealURL configuration and merges it with provided configuration
     *
     * @param       array $params Default configuration
     * @return      array Updated configuration
     */
    public function addQuestionaireConfig ($params)
    {
        $extensionConfiguration = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['questionaire']);

        $detailPidsArr = GeneralUtility::trimExplode(',', $extensionConfiguration['detailPids'], true);
        foreach ($detailPidsArr as $pid) {
            $overridesToMerge[$pid] = 'details';
        }

        $overridesToReplace = [
            'postVarSets' => array(
                'details' => array(
                    'survey' => array(
                        array(
                            'GETvar' => 'tx_questionaire_pi1[action]',
                            'valueMap' => array(
                                'show' => ''
                            ),
                            'noMatch' => 'bypass'
                        ),
                        array(
                            'GETvar' => 'tx_questionaire_pi1[controller]',
                            'valueMap' => array(
                                'Survey' => '',
                            ),
                            'noMatch' => 'bypass'
                        ),
                        array(
                            'GETvar' => 'tx_questionaire_pi1[survey]',
                            'lookUpTable' => array(
                                'table' => 'tx_questionaire_domain_model_survey',
                                'id_field' => 'uid',
                                'alias_field' => 'title',
                                'addWhereClause' => ' AND NOT deleted',
                                'useUniqueCache' => 1,
                                'useUniqueCache_conf' => array(
                                    'strtolower' => 1,
                                    'spaceCharacter' => '-',
                                ),
                                'autoUpdate' => 1,
                            ),
                        ),
                        array(
                            'GETvar' => 'tx_questionaire_pi1[key]'
                        ),

                    ),
                ),
            ),

        ];

        $array['postVarSets'] = array_replace($overridesToReplace['postVarSets'], $overridesToMerge);
        return array_merge_recursive($params['config'], $array);

    }
}

